RevocationReasonsResponse class

Respuesta tipada para la lista de razones de revocación.

Constructors

RevocationReasonsResponse({required List reasons})
const
RevocationReasonsResponse.fromJson(String source)
Crea la instancia a partir de un JSON (String).
factory
RevocationReasonsResponse.fromMap(Map<String, dynamic> map)
Crea la instancia a partir de un Map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
reasons List
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Convierte la instancia a JSON (String).
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited