GetCustomerData class

Payload de la respuesta de getCustomer.

Constructors

GetCustomerData({required String token, required Map<String, dynamic> userData})
const
GetCustomerData.fromJson(String source)
Crea la instancia a partir de un JSON (String).
factory
GetCustomerData.fromMap(Map<String, dynamic> map)
Crea la instancia a partir de un Map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
userData Map<String, dynamic>
final

Methods

copyWith({String? token, Map<String, dynamic>? userData}) GetCustomerData
Crea una copia con valores opcionalmente reemplazados.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Convierte la instancia a JSON (String).
toMap() Map<String, dynamic>
Convierte la instancia a un Map<String, dynamic>.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited