CreateApacuanaUserRequest class
Constructors
-
CreateApacuanaUserRequest({required String kinddoc, required String doc, String? email, int? typeuser, String? name, String? lastname, String? birthdate, String? gender, String? kindrif, String? rif, int? phone, String? kindphone, String? postalcode, String? address, String? fiscaladdress, String? fiscalkindphone, int? fiscalphone, String? occupation, String? degree, String? university, String? graduationyear, String? collegiatenumber, String? collegiateyear, String? companyname, String? companykindrif, String? companyrif, String? companystate, String? companymunicipality, String? companyparish, String? companyaddress, String? companykindphone, String? companyphone, String? companypostalcode, String? companywebpage, String? companycommercialregister, String? companyregisterdate, String? companyregisternumber, String? companyconstitutiondate, String? companypublishdate, String? companyconstitutiondecree, String? companynumberdecree, String? positionprivate, String? departmentprivate, String? authorizedprivate, String? functionsprivate, String? publishprivate, String? issuedateprivate, String? kindphoneprivate, int? phoneprivate, String? positionpublic, String? departmentpublic, String? authorizedpublic, String? functionspublic, String? publishpublic, String? issuedatepublic, String? kindphonepublic, int? phonepublic, String? companyid, Map<
String, dynamic> ? files}) -
const
-
CreateApacuanaUserRequest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address → String?
-
final
-
final
-
final
- birthdate → String?
-
final
- collegiatenumber → String?
-
final
- collegiateyear → String?
-
final
- companyaddress → String?
-
final
- companycommercialregister → String?
-
final
- companyconstitutiondate → String?
-
final
- companyconstitutiondecree → String?
-
final
- companyid → String?
-
final
- companykindphone → String?
-
final
- companykindrif → String?
-
final
- companymunicipality → String?
-
final
- companyname → String?
-
final
- companynumberdecree → String?
-
final
- companyparish → String?
-
final
- companyphone → String?
-
final
- companypostalcode → String?
-
final
- companypublishdate → String?
-
final
- companyregisterdate → String?
-
final
- companyregisternumber → String?
-
final
- companyrif → String?
-
final
- companystate → String?
-
final
- companywebpage → String?
-
final
- degree → String?
-
final
- departmentprivate → String?
-
final
- departmentpublic → String?
-
final
- doc → String
-
final
- email → String?
-
final
-
files
→ Map<
String, dynamic> ? -
final
- fiscaladdress → String?
-
final
- fiscalkindphone → String?
-
final
- fiscalphone → int?
-
final
- functionsprivate → String?
-
final
- functionspublic → String?
-
final
- gender → String?
-
final
- graduationyear → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuedateprivate → String?
-
final
- issuedatepublic → String?
-
final
- kinddoc → String
-
final
- kindphone → String?
-
final
- kindphoneprivate → String?
-
final
- kindphonepublic → String?
-
final
- kindrif → String?
-
final
- lastname → String?
-
final
- name → String?
-
final
- occupation → String?
-
final
- phone → int?
-
final
- phoneprivate → int?
-
final
- phonepublic → int?
-
final
- positionprivate → String?
-
final
- positionpublic → String?
-
final
- postalcode → String?
-
final
- publishprivate → String?
-
final
- publishpublic → String?
-
final
- rif → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeuser → int?
-
final
- university → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Convierte a Map<String, dynamic> para enviar al core/API. Omite valores nulos.
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void - Valida los campos obligatorios; lanza ArgumentError si faltan.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited