ApacuanaAPIError class

Clase de error personalizada para errores de la API de Apacuana.

Implemented types

Constructors

ApacuanaAPIError(String message, {int statusCode = 500, String? errorCode, StackTrace? stackTrace})

Properties

errorCode String?
Código de error específico de la API (opcional).
final
hashCode int
The hash code for this object.
no setterinherited
message String
Mensaje de error legible.
final
name String
Nombre del error (paridad con this.name = "ApacuanaAPIError" en JS).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
StackTrace opcional capturado al momento de crear/lanzar el error.
final
statusCode int
Código de estado HTTP asociado (por defecto 500).
final
success bool
Bandera de éxito para paridad con la versión JS (siempre false).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited