CertificateStatus enum
Values
- request → const CertificateStatus
-
const CertificateStatus("SOLICITUD") - generate → const CertificateStatus
-
const CertificateStatus("GENERAR") - current → const CertificateStatus
-
const CertificateStatus("VIGENTE") - revoque → const CertificateStatus
-
const CertificateStatus("REVOCADO") - expire → const CertificateStatus
-
const CertificateStatus("EXPIRADO") - requestRevoque → const CertificateStatus
-
const CertificateStatus("SOLICITUD_DE_REVOCACION") - certificateAnotherDevice → const CertificateStatus
-
const CertificateStatus("CERTIFICADO_EN_OTRO_DISPOSITIVO") - signPending → const CertificateStatus
-
const CertificateStatus("PENDIENTE_POR_FIRMAR")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String raw) → CertificateStatus?
Constants
-
values
→ const List<
CertificateStatus> - A constant List of the values in this enum, in order of their declaration.